"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const utils_1 = require("../utils");
const ByteToBitString_1 = require("./ByteToBitString");
/**
 * Converts a buffer to a string array
 * where each string is 8 characters of
 * either a 1 or a 0.
 *
 * @export
 * @param {Buffer} buffer
 * @param {BitOrder} [order=DEFAULT_BIT_ORDER]
 * @returns {string[]}
 */
function BufferToBitStringArray(buffer, endian = constants_1.DEFAULT_ENDIAN, order = constants_1.DEFAULT_BIT_ORDER) {
    const clonedBuffer = utils_1.CloneBuffer(buffer);
    if (endian === 'BE') {
        clonedBuffer.swap16();
    }
    const bytes = Array.from(clonedBuffer);
    return bytes.map(byte => ByteToBitString_1.ByteToBitString(byte, order));
}
exports.BufferToBitStringArray = BufferToBitStringArray;
//# sourceMappingURL=BufferToBitStringArray.js.map