"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const masks_1 = require("../masks");
const byte_1 = require("../byte");
const constants_1 = require("../../constants");
/**
 * Get the bit at pos.bit
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {BitIndex} bit
 * @returns {boolean}
 */
function GetBitAt(buffer, pos, bit, endian = constants_1.DEFAULT_ENDIAN) {
    const Mask = masks_1.GenerateDefaultMask();
    if (bit < 0)
        bit = 0;
    if (bit > 7)
        bit = 7;
    const byte = byte_1.GetUInt8At(buffer, pos, endian);
    return (byte & Mask[bit]) != 0;
}
exports.GetBitAt = GetBitAt;
/**
 * Set the bit at pos.bit
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {BitIndex} bit
 * @param {boolean} value
 */
function SetBitAt(buffer, pos, bit, value, endian = constants_1.DEFAULT_ENDIAN) {
    const Mask = masks_1.GenerateDefaultMask();
    if (bit < 0)
        bit = 0;
    if (bit > 7)
        bit = 7;
    let byte = byte_1.GetUInt8At(buffer, pos, endian);
    if (value) {
        byte = (byte | Mask[bit]);
    }
    else {
        byte = (byte & ~Mask[bit]);
    }
    byte_1.SetUInt8At(buffer, pos, byte, endian);
}
exports.SetBitAt = SetBitAt;
/**
 * Toggle the bit at pos.bit
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {BitIndex} bit
 */
function ToggleBitAt(buffer, pos, bit, endian = constants_1.DEFAULT_ENDIAN) {
    const currentValue = GetBitAt(buffer, pos, bit, endian);
    SetBitAt(buffer, pos, bit, !currentValue, endian);
}
exports.ToggleBitAt = ToggleBitAt;
//# sourceMappingURL=bit.js.map