"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const uint8_1 = require("./uint8");
const nibble_1 = require("../nibble");
function checkValidBCDNibble(bcdNibble) {
    if (bcdNibble > 10) {
        throw new Error('Invalid BCD Buffer');
    }
}
/**
 * Binary-Coded Decimal to Byte
 *
 * @export
 * @param {number} bcd
 * @returns {number}
 */
function BCDtoByte(bcd) {
    const lsn = nibble_1.GetByteNibble(bcd, constants_1.NibbleSignificance.least);
    const msn = nibble_1.GetByteNibble(bcd, constants_1.NibbleSignificance.most);
    checkValidBCDNibble(lsn);
    checkValidBCDNibble(msn);
    return (msn * 10) + lsn;
}
exports.BCDtoByte = BCDtoByte;
/**
 * Byte to Binary-Coded Decimal
 *
 * @export
 * @param {number} byte
 * @returns {number}
 */
function ByteToBCD(byte) {
    return (((byte / 10) << 4) | (byte % 10));
}
exports.ByteToBCD = ByteToBCD;
/**
 * Get Binary-Coded Decimal value at specific byte
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {number}
 */
function GetBCDAt(buffer, pos, endian = constants_1.DEFAULT_ENDIAN) {
    return ByteToBCD(uint8_1.GetUInt8At(buffer, pos, endian));
}
exports.GetBCDAt = GetBCDAt;
/**
 * Set Binary-Coded Decimal value at specific byte
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} bcdValue
 */
function SetBCDAt(buffer, pos, bcdValue, endian = constants_1.DEFAULT_ENDIAN) {
    uint8_1.SetUInt8At(buffer, pos, BCDtoByte(bcdValue), endian);
}
exports.SetBCDAt = SetBCDAt;
//# sourceMappingURL=bcd.js.map