"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const toFixed_1 = require("./toFixed");
/**
 * Get 32 bit float value
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} [precision=3]
 * @param {Endian} [endian='LE']
 * @returns {number}
 */
function GetFloat32At(buffer, pos, precision = constants_1.FLOAT32_DEFAULT_PRECISION, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            return toFixed_1.toFixed(buffer.readFloatBE(pos), precision);
        case 'LE':
            return toFixed_1.toFixed(buffer.readFloatLE(pos), precision);
    }
}
exports.GetFloat32At = GetFloat32At;
/**
 * Set 32 bit float value
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 * @param {Endian} [endian='LE']
 * @returns {void}
 */
function SetFloat32At(buffer, pos, value, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            buffer.writeFloatBE(value, pos);
            break;
        case 'LE':
            buffer.writeFloatLE(value, pos);
            break;
    }
    return;
}
exports.SetFloat32At = SetFloat32At;
//# sourceMappingURL=float32.js.map