"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const toFixed_1 = require("./toFixed");
/**
 * Get 64 bit double value
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {Endian} [endian='LE']
 * @returns {number}
 */
function GetFloat64At(buffer, pos, precision = constants_1.FLOAT64_DEFAULT_PRECISION, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            return toFixed_1.toFixed(buffer.readDoubleBE(pos), precision);
        case 'LE':
            return toFixed_1.toFixed(buffer.readDoubleLE(pos), precision);
    }
}
exports.GetFloat64At = GetFloat64At;
/**
 * Set 64 bit double value
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 * @param {Endian} [endian='LE']
 * @returns {void}
 */
function SetFloat64At(buffer, pos, value, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            buffer.writeDoubleBE(value, pos);
            break;
        case 'LE':
            buffer.writeDoubleLE(value, pos);
            break;
    }
    return;
}
exports.SetFloat64At = SetFloat64At;
//# sourceMappingURL=float64.js.map