"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
/**
 * Get 16 bit signed value -32768..32767
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {Endian} [endian='LE'] the endian to use, defaults to little endian
 * @returns {number}
 */
function GetInt16At(buffer, pos, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            return buffer.readInt16BE(pos);
        case 'LE':
            return buffer.readInt16LE(pos);
    }
}
exports.GetInt16At = GetInt16At;
/**
 * Set 16 bit signed value -32768..32767
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 * @param {Endian} [endian='LE'] the endian to use, defaults to little endian
 */
function SetInt16At(buffer, pos, value, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            buffer.writeInt16BE(value, pos);
            break;
        case 'LE':
            buffer.writeInt16LE(value, pos);
            break;
    }
    return;
}
exports.SetInt16At = SetInt16At;
//# sourceMappingURL=int16.js.map