"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
/**
 * Get 32 bit signed value -2147483648..2147483647
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {Endian} [endian='LE'] the endian to use, defaults to little endian
 * @returns {number}
 */
function GetInt32At(buffer, pos, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            return buffer.readInt32BE(pos);
        case 'LE':
            return buffer.readInt32LE(pos);
    }
}
exports.GetInt32At = GetInt32At;
/**
 * Set 32 bit signed value -2147483648..2147483647
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 * @param {Endian} [endian='LE'] the endian to use, defaults to little endian
 */
function SetInt32At(buffer, pos, value, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            buffer.writeInt32BE(value, pos);
            break;
        case 'LE':
            buffer.writeInt32LE(value, pos);
            break;
    }
    return;
}
exports.SetInt32At = SetInt32At;
//# sourceMappingURL=int32.js.map