/// <reference types="node" />
import { Endian } from "../../constants";
/**
 * Get 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {bigint}
 */
export declare function GetLIntAt(buffer: Buffer, pos: number, endian?: Endian): bigint;
/**
 * Get 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * Node.js versions below 12.0.0 do not support `bigint` data type,
 * so the following code will attempt to calculate the Int64 value,
 * but at the outer ranges these values will have rounding errors.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {number}
 */
export declare function GetLIntAt_UNSAFE(buffer: Buffer, pos: number, endian?: Endian): number;
/**
 * Get 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {bigint}
 * @alias GetLIntAt
 */
export declare function GetInt64(buffer: Buffer, pos: number, endian?: Endian): bigint;
/**
 * Get 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * Node.js versions below 12.0.0 do not support `bigint` data type,
 * so the following code will attempt to calculate the Int64 value,
 * but at the outer ranges these values will have rounding errors.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {number}
 * @alias GetLIntAt_UNSAFE
 */
export declare function GetInt64_UNSAFE(buffer: Buffer, pos: number, endian?: Endian): number;
/**
 * Set 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {bigint} value
 */
export declare function SetLIntAt(buffer: Buffer, pos: number, value: bigint, endian?: Endian): void;
/**
 * Set 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * Node.js versions below 12.0.0 do not support `bigint` data type,
 * so the following code will attempt to calculate the Int64 value,
 * but at the outer ranges these values will have rounding errors.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 */
export declare function SetLIntAt_UNSAFE(buffer: Buffer, pos: number, value: number, endian?: Endian): void;
/**
 * Set 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {bigint} value
 * @alias SetLIntAt
 */
export declare function SetInt64(buffer: Buffer, pos: number, value: bigint, endian?: Endian): void;
/**
 * Set 64 bit signed value -9223372036854775808..9223372036854775807
 *
 * Node.js versions below 12.0.0 do not support `bigint` data type,
 * so the following code will attempt to calculate the Int64 value,
 * but at the outer ranges these values will have rounding errors.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 * @alias SetLIntAt_UNSAFE
 */
export declare function SetInt64_UNSAFE(buffer: Buffer, pos: number, value: number, endian?: Endian): void;
