"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const string_1 = require("../string");
/**
 * Get 16 bit unsigned value 0..65535
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {number}
 */
function GetUInt16At(buffer, pos, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            return buffer.readUInt16BE(pos);
        case 'LE':
            return buffer.readUInt16LE(pos);
    }
}
exports.GetUInt16At = GetUInt16At;
/**
 * Set 16 bit unsigned value 0..65535
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {number} value
 */
function SetUInt16At(buffer, pos, value, endian = constants_1.DEFAULT_ENDIAN) {
    switch (endian) {
        case 'BE':
            buffer.writeUInt16BE(value, pos);
            break;
        case 'LE':
            buffer.writeUInt16LE(value, pos);
            break;
    }
    return;
}
exports.SetUInt16At = SetUInt16At;
/**
 * Gets a binary string representation of the target uint16
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {('reversed' | 'normal')} [order='reversed']
 * @returns
 */
function GetUInt16BinaryString(buffer, pos, order = constants_1.DEFAULT_BIT_ORDER) {
    const word = GetUInt16At(buffer, pos);
    const string = word.toString(2);
    const filledString = '0000000000000000'.substr(string.length) + string;
    switch (order) {
        case 'normal':
            return filledString;
        default:
            return string_1.ReverseString(filledString);
    }
}
exports.GetUInt16BinaryString = GetUInt16BinaryString;
//# sourceMappingURL=uint16.js.map