"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const byte_1 = require("../byte");
/**
 * Gets a nibble at a specific byte in the buffer
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} bytePos
 * @param {NibbleSignificance} significance
 * @param {Endian} [endian=DEFAULT_ENDIAN]
 * @returns {number}
 */
function GetNibbleAt(buffer, bytePos, significance, endian = constants_1.DEFAULT_ENDIAN) {
    const byte = byte_1.GetUInt8At(buffer, bytePos, endian);
    return GetByteNibble(byte, significance);
}
exports.GetNibbleAt = GetNibbleAt;
/**
 * Sets a nibble at a specific byte in the buffer
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} bytePos
 * @param {NibbleSignificance} significance
 * @param {number} nibbleValue
 * @param {Endian} [endian=DEFAULT_ENDIAN]
 * @returns {void}
 */
function SetNibbleAt(buffer, bytePos, significance, nibbleValue, endian = constants_1.DEFAULT_ENDIAN) {
    const byte = byte_1.GetUInt8At(buffer, bytePos, endian);
    return byte_1.SetUInt8At(buffer, bytePos, SetByteNibble(byte, significance, nibbleValue));
}
exports.SetNibbleAt = SetNibbleAt;
function GetByteNibble(byte, significance) {
    const position = significance * 4;
    const nibble = (byte >> position) & 0x0f;
    return nibble;
}
exports.GetByteNibble = GetByteNibble;
function SetByteNibble(byte, significance, nibbleValue) {
    let res = byte;
    res &= 0xF0;
    const position = significance * 4;
    res |= ((nibbleValue << position) & 0x0f);
    return res;
}
exports.SetByteNibble = SetByteNibble;
//# sourceMappingURL=nibble.js.map