/// <reference types="node" />
export declare type IPV4Array = [number, number, number, number];
/**
 * Gets an IPV4 IP Address from the buffer at a specific position,
 * and returns it as a number array of length 4.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {[number, number, number, number]}
 */
export declare function GetIPV4AddressAt(buffer: Buffer, pos: number): IPV4Array;
/**
 * Sets an IPV4 IP Address in the buffer at a specific position
 *
 * @export
 * @param {Buffer} buffer the buffer to write the ipv4 address to
 * @param {number} pos position to start the write operation
 * @param {(IPV4Array | number[] | Buffer | ArrayLike<number> | string)} ipv4Address ip address
 */
export declare function SetIPV4AddressAt(buffer: Buffer, pos: number, ipv4Address: IPV4Array): void;
export declare function SetIPV4AddressAt(buffer: Buffer, pos: number, ipv4Address: number[]): void;
export declare function SetIPV4AddressAt(buffer: Buffer, pos: number, ipv4Address: Buffer): void;
export declare function SetIPV4AddressAt(buffer: Buffer, pos: number, ipv4Address: ArrayLike<number>): void;
export declare function SetIPV4AddressAt(buffer: Buffer, pos: number, ipv4Address: string): void;
/**
 * Gets an IPV4 IP Address from the buffer at a specific position,
 * and converts it into the format: `${ip1}.${ip2}.${ip3}.${ip4}`
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {string}
 */
export declare function GetIPV4AddressAsStringAt(buffer: Buffer, pos: number): string;
