"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Gets an IPV4 IP Address from the buffer at a specific position,
 * and returns it as a number array of length 4.
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {[number, number, number, number]}
 */
function GetIPV4AddressAt(buffer, pos) {
    const ipv4Address = buffer.slice(pos, pos + 4);
    return [
        ipv4Address[0],
        ipv4Address[1],
        ipv4Address[2],
        ipv4Address[3],
    ];
}
exports.GetIPV4AddressAt = GetIPV4AddressAt;
function SetIPV4AddressAt(buffer, pos, ipv4Address) {
    if (typeof ipv4Address === 'string') {
        ipv4Address = ipv4Address.split('.').map(value => Number(value));
    }
    buffer[pos + 0] = ipv4Address[0];
    buffer[pos + 1] = ipv4Address[1];
    buffer[pos + 2] = ipv4Address[2];
    buffer[pos + 3] = ipv4Address[3];
}
exports.SetIPV4AddressAt = SetIPV4AddressAt;
/**
 * Gets an IPV4 IP Address from the buffer at a specific position,
 * and converts it into the format: `${ip1}.${ip2}.${ip3}.${ip4}`
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @returns {string}
 */
function GetIPV4AddressAsStringAt(buffer, pos) {
    return GetIPV4AddressAt(buffer, pos).join('.');
}
exports.GetIPV4AddressAsStringAt = GetIPV4AddressAsStringAt;
//# sourceMappingURL=ipv4.js.map