"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const byte_1 = require("../byte");
var BCDDateIndex;
(function (BCDDateIndex) {
    BCDDateIndex[BCDDateIndex["YEAR"] = 0] = "YEAR";
    BCDDateIndex[BCDDateIndex["MONTH"] = 1] = "MONTH";
    BCDDateIndex[BCDDateIndex["DAY"] = 2] = "DAY";
    BCDDateIndex[BCDDateIndex["HOUR"] = 3] = "HOUR";
    BCDDateIndex[BCDDateIndex["MINUTE"] = 4] = "MINUTE";
    BCDDateIndex[BCDDateIndex["SECOND"] = 5] = "SECOND";
    BCDDateIndex[BCDDateIndex["MSEC_HIGH"] = 6] = "MSEC_HIGH";
    BCDDateIndex[BCDDateIndex["MSEC_LOW"] = 7] = "MSEC_LOW";
})(BCDDateIndex || (BCDDateIndex = {}));
/**
 * Get S7 DateTime from buffer at a starting position
 *
 * @export
 * @param {Buffer} buffer buffer containing the date time
 * @param {number} pos starting position
 * @returns
 */
function GetS7DateTimeAt(buffer, pos) {
    let year = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.YEAR]);
    if (year < 90) {
        year += 2000;
    }
    else {
        year += 1900;
    }
    const month = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.MONTH]) - 1;
    const dayOfMonth = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.DAY]);
    const hour = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.HOUR]);
    const minute = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.MINUTE]);
    const second = byte_1.BCDtoByte(buffer[pos + BCDDateIndex.SECOND]);
    const millisecond = (byte_1.BCDtoByte(buffer[pos + BCDDateIndex.MSEC_HIGH]) * 10) + (byte_1.BCDtoByte(buffer[pos + BCDDateIndex.MSEC_LOW]) / 10);
    try {
        return new Date(year, month, dayOfMonth, hour, minute, second, millisecond);
    }
    catch (error) {
        return new Date(0);
    }
}
exports.GetS7DateTimeAt = GetS7DateTimeAt;
/**
 * Set S7 DateTime from buffer at a starting position
 *
 * @export
 * @param {Buffer} buffer
 * @param {number} pos
 * @param {Date} date
 */
function SetS7DateTimeAt(buffer, pos, date) {
    let year = date.getFullYear();
    if (year > 1999) {
        year -= 2000;
    }
    const month = date.getMonth() + 1;
    const day = date.getDate();
    const hour = date.getHours();
    const minutes = date.getMinutes();
    const seconds = date.getSeconds();
    const dayOfWeek = date.getDay() + 1;
    // MilliSecondHigh = First two digits of miliseconds 
    const MilliSecondHigh = date.getMilliseconds() / 10;
    // MilliSecondLow = Last digit of miliseconds
    const MilliSecondLow = date.getMilliseconds() % 10;
    buffer[pos + BCDDateIndex.YEAR] = byte_1.ByteToBCD(year);
    buffer[pos + BCDDateIndex.MONTH] = byte_1.ByteToBCD(month);
    buffer[pos + BCDDateIndex.DAY] = byte_1.ByteToBCD(day);
    buffer[pos + BCDDateIndex.HOUR] = byte_1.ByteToBCD(hour);
    buffer[pos + BCDDateIndex.MINUTE] = byte_1.ByteToBCD(minutes);
    buffer[pos + BCDDateIndex.SECOND] = byte_1.ByteToBCD(seconds);
    buffer[pos + BCDDateIndex.MSEC_HIGH] = byte_1.ByteToBCD(MilliSecondHigh);
    buffer[pos + BCDDateIndex.MSEC_LOW] = byte_1.ByteToBCD(MilliSecondLow * 10 + dayOfWeek);
}
exports.SetS7DateTimeAt = SetS7DateTimeAt;
//# sourceMappingURL=s7-datetime.js.map